@@ -1,4 +1,5 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .builder import build_iou_calculator
 from .rotate_iou2d_calculator import RBboxOverlaps2D, rbbox_overlaps
 
-__all__ = ['RBboxOverlaps2D', 'rbbox_overlaps']
+__all__ = ['build_iou_calculator', 'RBboxOverlaps2D', 'rbbox_overlaps']
